@@ -4,9 +4,12 @@
 function startFarabi(editorId) {
 
 	// Cache dialog jQuery references for later use
-	var $perl_critic_dialog = $('#perl_critic_dialog');
-	var $about_dialog = $('#about_dialog');
-	var $help_dialog = $("#help_dialog");
+	var $perl_critic_dialog = $('#perl-critic-dialog');
+	var $about_dialog = $('#about-dialog');
+	var $help_dialog = $("#help-dialog");
+	var $runDialog = $("#run-dialog");
+	var $openFileDialog    = $("#open-file-dialog");
+	var $optionsDialog = $("#options-dialog");
 
 	$("#theme_selector").change(function() {
 		var $selectedTheme = $(":selected", this);
@@ -127,9 +130,6 @@ function startFarabi(editorId) {
 			"F1": function(cm) {
 				displayHelp(cm);
 			},
-			"F5": function(cm) {
-				$(".run_in_browser_button").click();
-			}
 		}
 	});
 
@@ -186,21 +186,9 @@ function startFarabi(editorId) {
 
 	$(".results").hide();
 
-	$(".run_in_browser_button").click(function() {
-		// Load Perlito - Perl 5 to JS Compiler
-		$.ajax({
-			url: 'assets/perlito/perlito5.min.js',
-			dataType: "script",
-			cache: true,
-			success: function() {
-				runOnPerlito5(editor.getValue());
-			}
-		});
-	});
-
 	var $output = $("#output");
 
-	$(".perl_tidy_button").click(function() {
+	$(".perl-tidy-button").click(function() {
 		$.post('/perl_tidy', {"source": editor.getValue()}, function(data) {
 			if(data.error == '') {
 				editor.setValue(data.source);
@@ -210,24 +198,152 @@ function startFarabi(editorId) {
 		});
 	});
 
-	$(".perl_execute_button").click(function() {
-		$.post('/perl_execute', {"source": editor.getValue()}, function(data) {
-			var $output = $('#output');
-			$output.val('');
-			
-			// Handle STDERR
-			if (data.stderr.length) {
-				$output.val(data.stderr + "\n");
-			}
-			
-			// Handle STDOUT
-			$output.val($output.val() + data.stdout + "\nExit code: " + data.exit);
-			
-			// Show output tab
-			$('a[href="#output-tab"]').tab('show');
-		});
+	$(".open-file-button").click(function() {
+		$openFileDialog.modal('show');
+		$("#file", $openFileDialog).val('').focus();
+		$("#search-results", $openFileDialog).empty();
+		$("#ok-button", $openFileDialog).attr("disabled","disabled");
 	});
 
+	$(".open-url-button").click(function() {
+		var url = prompt("Please Enter a http/https file location:" + 
+			"\ne.g https://raw.github.com/ihrd/uri/master/lib/URI.pm");
+		if(!url) {
+			return;
+		}
+		$.post('/open_url',
+        	{ "url": url },
+           	function(code) {
+            	editor.setValue(code);
+            }
+        );
+	});
+
+	$(".new-file-button").click(function() {
+		alert("TODO new file");
+	});
+
+	$(".syntax-check-button").click(function() {
+		alert("TODO syntax check");
+	});
+
+	$(".perl-critic-button").click(function() {
+		alert("TODO perl critic");
+	});
+
+	$(".options-button").click(function() {
+		$optionsDialog.modal('show');
+		$("#mode_selector", $optionsDialog).focus();
+	});
+
+
+	$(".run-button").click(function() {
+		
+		$runDialog.modal('show');
+		$("#runtime", $runDialog).focus().change();
+	});
+
+	$("#runtime").keypress(function(evt) {
+		if(evt.keyCode == 13) {
+			$("#ok-button", $runDialog).click();
+		}
+	});
+
+	var runtimeHelp = {
+		"rakudo"    : {
+			text    : "<b>Rakudo</b> Perl 6, or simply Rakudo, is a compiler for the Perl 6 programming language. It runs on the Parrot virtual machine.",
+			url     : "http://rakudo.org/about",
+		},
+		"niecza"    : {
+			text    : "<b>Niecza</b> is a Perl 6 implementation focusing on optimization and efficient implementation research. It targets the Common Language Runtime (<a href='http://en.wikipedia.org/wiki/Common_Language_Infrastructure' target='_blank'>ECMA-335</a>; implementations are 'Mono' and '.NET').",
+			url     : "https://github.com/sorear/niecza/blob/master/README.pod",
+		},
+		"perl": {
+			text    : "<b>Perl 5</b> is a highly capable, feature-rich programming language with over 24 years of development.",
+			url     : "http://perl.org",
+		},	
+		"perlito-6" : {
+			text    : "<b>Perlito 6</b> is a compiler collection that implements a subset of Perl 6.",
+			url     : "http://perlito.org",
+		},
+		"perlito-5" : {
+			text    : "<b>Perlito 5</b> is a compiler collection that implements a subset of Perl 5.",
+			url     : "http://perlito.org",
+		},
+	};
+
+	$("#runtime").change(function() {
+		var runtime = $(":selected", $(this)).attr('id');
+		var help = runtimeHelp[runtime];
+		$("#help", $runDialog).html(help.text + "<br><a href='" + help.url + "' target='_blank'>More information...</a>");
+	});
+
+	$("#ok-button", $runDialog).click(function() {
+			
+		var runtime = $("#runtime :selected", $runDialog).attr('id');
+		if(runtime == "perlito-6") {
+			// Perlito 6
+			if(typeof p6pkg != 'undefined') {
+                                runOnPerlito6(editor.getValue());
+                        } else {
+                                // Load Perlito and then run
+                                $.ajax({
+                                        url: 'assets/perlito/perlito6.min.js',
+                                        dataType: "script",
+                                        success: function() {
+                                                runOnPerlito6(editor.getValue());
+                                        }
+                                });
+                        }
+		} else if(runtime == "perlito-5") {
+			// Perlito 5
+			if(typeof p5pkg != 'undefined') {
+				runOnPerlito5(editor.getValue());
+			} else {
+				// Load Perlito and then run
+				$.ajax({
+					url: 'assets/perlito/perlito5.min.js',
+					dataType: "script",
+					success: function() {
+						runOnPerlito5(editor.getValue());
+					}
+				});
+			}
+		} else if(runtime == "perl") { 
+			// Perl
+			$.post('/run_perl', {"source": editor.getValue() }, function(result) {
+				show_cmd_output(result);
+			});
+		} else if(runtime == "rakudo") {
+			// Rakudo Perl 6
+			$.post('/run_rakudo', {"source": editor.getValue() }, function(result) {
+				show_cmd_output(result);
+			});
+		} else if(runtime == "niecza") {
+			// Niecza
+			$.post('/run_niecza', {"source": editor.getValue() }, function(result) {
+				show_cmd_output(result);
+			});
+		}
+	});
+
+
+	var show_cmd_output = function(data) {
+		var $output = $('#output');
+		$output.val('');
+			
+		// Handle STDERR
+		if (data.stderr.length) {
+			$output.val(data.stderr + "\n");
+		}
+		
+		// Handle STDOUT
+		$output.val($output.val() + data.stdout + "\nExit code: " + data.exit);
+		
+		// Show output tab
+		$('a[href="#output-tab"]').tab('show');
+	};
+
 	var perlCriticWidgets = [];
 
 	var perl_critic = function() {
@@ -346,6 +462,9 @@ function startFarabi(editorId) {
 	$perl_critic_dialog.hide().on('hidden', onCloseFocusEditor);
 	$about_dialog.hide().on('hidden', onCloseFocusEditor);
 	$help_dialog.hide().on('hidden', onCloseFocusEditor);
+	$runDialog.hide().on('hidden', onCloseFocusEditor);
+	$openFileDialog.hide().on('hidden', onCloseFocusEditor);
+	$optionsDialog.hide().on('hidden', onCloseFocusEditor);
 
 	$(".topic").typeahead({
 		source : function(query, process) {
@@ -450,6 +569,31 @@ function runOnPerlito5(source) {
 
 }
 
+function runOnPerlito6(source) {
+	var $output = $('#output');
+	window.print = function(s) {
+		$output.val($output.val() + s + "\n");
+	}
+        var ast;
+	var match;
+	$output.val('');
+	try {
+                // compilation unit
+                match = Perlito6$Grammar.exp_stmts(source, 0);
+                ast = match.scalar();
+                tmp = {v_name:"GLOBAL", v_body: ast}; 
+                tmp.__proto__ = CompUnit; 
+                ast = tmp;
+		eval(ast.emit_javascript());
+	} catch(err) {
+                // Show error in output tab
+                $output.val("Error:\n" + perl(err) + "\nCompilation aborted.\n");
+	}
+
+        // Show output tab
+        $('a[href="#output-tab"]').tab('show');
+}
+
 // Start Farabi when the document loads
 $(function() {
 	startFarabi("editor");
